import { InterstitialAdErrorEvent } from "./InterstitialAdErrorEvent";
/**
 * 插屏广告组件。插屏广告组件是一个原生组件，层级比普通组件高。插屏广告组件每次创建都会返回一个全新的实例（小程序端的插屏广告实例不允许跨页面使用），默认是隐藏的，需要调用 InterstitialAd.show() 将其显示。
 *
 */
export interface InterstitialAd {
    /**
     * 加载插屏广告。
     */
    load(): Promise<void>;
    /**
     * 显示插屏广告。
     */
    show(): Promise<void>;
    /**
     * 销毁插屏广告实例。
     */
    destroy(): void;
    /**
     * 监听插屏广告加载事件。。
     * @param callback 插屏广告加载事件的监听函数。
     */
    onLoad(callback: () => void): void;
    /**
     * 取移除插屏广告加载事件的监听函数。
     * @param callback onLoad 传入的监听函数。不传此参数则移除所有监听函数。
     */
    offLoad(callback?: () => void): void;
    /**
     * 监听插屏错误事件。
     * @param callback 插屏错误事件的监听函数。
     */
    onError(callback: (event: InterstitialAdErrorEvent) => void): void;
    /**
     * 移除插屏错误事件的监听函数。
     * @param callback onError 传入的监听函数。不传此参数则移除所有监听函数。
     */
    offError(callback?: (event: InterstitialAdErrorEvent) => void): void;
    /**
     * 监听插屏广告关闭事件。
     * @param callback 插屏广告关闭事件的监听函数。
     */
    onClose(callback: () => void): void;
    /**
     * 移除插屏广告关闭事件的监听函数。
     * @param callback onClose 传入的监听函数。不传此参数则移除所有监听函数。
     */
    offClose(callback?: () => void): void;
}
