import { RewardedVideoAdCloseEvent } from "./RewardedVideoAdCloseEvent";
import { RewardedVideoAdErrorEvent } from "./RewardedVideoAdErrorEvent";
/**
 * 激励视频广告。
 */
export interface RewardedVideoAd {
    /**
     * 加载激励视频广告数据。
     */
    load(): Promise<void>;
    /**
     * 展示激励视频广告。
     */
    show(): Promise<void>;
    /**
     * 销毁激励视频广告实例。
     */
    destroy(): void;
    /**
     * 监听激励视频广告加载事件。
     * @param callback 激励视频广告加载事件的回调函数
     */
    onLoad(callback: () => void): void;
    /**
     * 取消监听激励视频广告加载事件。不传入 `callback` 则取消所有监听。
     * @param callback 激励视频广告加载事件的回调函数
     */
    offLoad(callback?: () => void): void;
    /**
     * 监听激励视频广告出错事件。
     * @param callback 激励视频广告出错事件的回调函数
     */
    onError(callback: (event: RewardedVideoAdErrorEvent) => void): void;
    /**
     * 取消监听激励视频广告出错事件。不传入 `callback` 则取消所有监听。
     * @param callback 激励视频广告出错事件的回调函数
     */
    offError(callback?: (event: RewardedVideoAdErrorEvent) => void): void;
    /**
     * 监听激励视频广告关闭事件。
     * @param callback 激励视频广告关闭事件的回调函数
     */
    onClose(callback: (event: RewardedVideoAdCloseEvent) => void): void;
    /**
     * 取消监听激励视频广告关闭事件。不传入 `callback` 则取消所有监听。
     * @param callback 激励视频广告关闭事件的回调函数
     */
    offClose(callback?: (event: RewardedVideoAdCloseEvent) => void): void;
}
