import { NavigateToOptions } from "./NavigateToOptions";
import { NavigateBackOptions } from "./NavigateBackOptions";
import { NavigateToResult } from "./NavigateToResult";
import { RedirectToOptions } from "./RedirectToOptions";
import { ReLaunchOptions } from "./ReLaunchOptions";
import { SwitchTabOptions } from "./SwitchTabOptions";
export declare class RouteAPI {
    /**
     * 保留当前页面，跳转到应用内的某个页面。不能跳转到 tabBar 页面。小程序页面栈的最大深度为六层。
     * @param options
     * @returns
     * @errinfo [{"errMsg":"app not in foreground","errDesc":"当前小程序未在前台"},{"errMsg":"page xxx is not found","errDesc":"页面未找到"},{"errMsg":"can not navigateTo a tabbar page","errDesc":"不能跳转到tabbar页面"},{"errMsg":"reach max WebView Depth x","errDesc":"超过页面栈最大深度"}]
     * @example
     * ```javascript
     * ks.navigateTo({
     *     url: 'pages/xx/xx?data=123',
     * });
     *
     * // navigate to Page
     * Page({
     *     onLoad(query) {
     *         console.log(query.data);
     *     },
     * });
     *
     * ```
     *
     */
    navigateTo(options: NavigateToOptions): Promise<NavigateToResult>;
    /**
     * 关闭当前页面，返回上一页面或多级页面。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.navigateBack({
     *     delta: 1,
     * });
     *
     * ```
     *
     */
    navigateBack(options?: NavigateBackOptions): Promise<void>;
    /**
     * 关闭当前页面，跳转到应用内的某个页面。不能跳转到 tabBar 页面。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.redirectTo({
     *     url: 'pages/xx/xx?data=123',
     * });
     *
     * // redirect to Page
     * Page({
     *     onLoad(query) {
     *         console.log(query.data);
     *     },
     * });
     *
     * ```
     *
     */
    redirectTo(options: RedirectToOptions): Promise<void>;
    /**
     * 关闭所有页面，打开到应用内的某个页面
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.reLaunch({
     *     url: 'pages/xx/xx?data=123',
     * });
     *
     * // reLaunch to Page
     * Page({
     *     onLoad(query) {
     *         console.log(query.data);
     *     },
     * });
     *
     * ```
     *
     */
    reLaunch(options: ReLaunchOptions): Promise<void>;
    /**
     * 跳转到 tabBar 页面，并关闭其他所有非 tabBar 页面
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.switchTab({
     *     url: 'pages/xx',
     * });
     *
     * ```
     *
     */
    switchTab(options: SwitchTabOptions): Promise<void>;
}
