import { CanvasContext } from "./CanvasContext";
import { CanvasGetImageDataOptions } from "./CanvasGetImageDataOptions";
import { CanvasGetImageDataResult } from "./CanvasGetImageDataResult";
import { CanvasToTempFilePathOptions } from "./CanvasToTempFilePathOptions";
import { CanvasToTempFilePathResult } from "./CanvasToTempFilePathResult";
export declare class CanvasAPI {
    /**
     * 创建画布上下文。
     * @param canvasId `canvas` 组件的 `canvas-id` 属性
     * @returns 画布上下文
     *
     * @example
     * ```javascript
     * const ctx = ks.createCanvasContext('myCanvas');
     * ctx.setFillStyle('red');
     * ctx.fillRect(10, 10, 150, 100);
     * ctx.draw();
     * ctx.fillRect(50, 50, 150, 100);
     * ctx.draw(true);
     *
     * ```
     *
     */
    createCanvasContext(canvasId: string): CanvasContext;
    /**
     * 获取画布指定区域的像素数据。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const { width, height, data } = await ks.canvasGetImageData({
     *     canvasId: 'myCanvas',
     *     x: 0,
     *     y: 0,
     *     width: 100,
     *     height: 100,
     * });
     *
     * ```
     *
     */
    canvasGetImageData(options: CanvasGetImageDataOptions): Promise<CanvasGetImageDataResult>;
    /**
     * 把当前画布指定区域的内容导出生成指定大小的图片。在 draw() 回调里调用该方法才能保证图片导出成功。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const { tempFilePath } = await ks.canvasToTempFilePath({
     *     x: 100,
     *     y: 200,
     *     width: 50,
     *     height: 50,
     *     destWidth: 100,
     *     destHeight: 100,
     *     canvasId: 'myCanvas',
     * });
     *
     * ```
     *
     */
    canvasToTempFilePath(options: CanvasToTempFilePathOptions): Promise<CanvasToTempFilePathResult>;
}
