import { AccelerometerChangeEvent } from "./AccelerometerChangeEvent";
import { StartAccelerometerOptions } from "./StartAccelerometerOptions";
import { StopAccelerometerOptions } from "./StopAccelerometerOptions";
export declare class AccelerometerAPI {
    /**
     * 开始监听加速度数据变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.startAccelerometer({
     *     interval: 'normal',
     * });
     *
     * ks.onAccelerometerChange((event) => {
     *     console.log(event.x, event.y, event.z);
     * });
     *
     * ```
     *
     */
    startAccelerometer(options?: StartAccelerometerOptions): Promise<void>;
    /**
     * 停止监听加速度数据变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.startAccelerometer({
     *     interval: 'normal',
     * });
     *
     * ks.onAccelerometerChange((event) => {
     *     console.log(event.x, event.y, event.z);
     * });
     *
     * setTimeout(async () => {
     *     await ks.stopAccelerometer();
     * }, 3000);
     *
     * ```
     *
     */
    stopAccelerometer(options?: StopAccelerometerOptions): Promise<void>;
    /**
     * 监听加速度数据变化事件。
     * @param callback 加速度数据变化事件的回调函数
     *
     * @example
     * ```javascript
     * await ks.startAccelerometer({
     *     interval: 'normal',
     * });
     *
     * ks.onAccelerometerChange((event) => {
     *     console.log(event.x, event.y, event.z);
     * });
     *
     * ```
     *
     */
    onAccelerometerChange(callback: (event: AccelerometerChangeEvent) => void): void;
    /**
     * 取消监听加速度数据变化事件。不传入 `callback` 则取消所有监听。
     * @param callback 加速度数据变化事件的回调函数
     *
     * @example
     * ```javascript
     * await ks.startAccelerometer({
     *     interval: 'normal',
     * });
     *
     * function handleAccelerometerChange(event) {
     *     console.log(event.x, event.y, event.z);
     * }
     *
     * ks.onAccelerometerChange(handleAccelerometerChange);
     *
     * setTimeout(async () => {
     *     ks.offAccelerometerChange(handleAccelerometerChange);
     *     await ks.stopAccelerometer();
     * }, 3000);
     *
     * ```
     *
     */
    offAccelerometerChange(callback?: (event: AccelerometerChangeEvent) => void): void;
}
