import { GetClipboardDataOptions } from "./GetClipboardDataOptions";
import { GetClipboardDataResult } from "./GetClipboardDataResult";
import { SetClipboardDataOptions } from "./SetClipboardDataOptions";
export declare class ClipboardAPI {
    /**
     * 获取系统剪贴板数据。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const { data } = await ks.getClipboardData();
     * console.log(data);
     *
     * ```
     *
     */
    getClipboardData(options?: GetClipboardDataOptions): Promise<GetClipboardDataResult>;
    /**
     * 设置系统剪贴板数据。接口调用成功后，会弹出 Toast 提示 “内容已复制”，时长持续 1.5s。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.setClipboardData({
     *     data: 'hello world',
     * });
     *
     * const { data } = await ks.getClipboardData();
     *
     * console.log(data); // hello world
     *
     * ```
     *
     */
    setClipboardData(options: SetClipboardDataOptions): Promise<void>;
}
