import { CompassChangeEvent } from "./CompassChangeEvent";
import { StartCompassOptions } from "./StartCompassOptions";
import { StopCompassOptions } from "./StopCompassOptions";
export declare class CompassAPI {
    /**
     * 开始监听罗盘数据变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.startCompass();
     * ks.onCompassChange((event) => {
     *     console.log(event.direction);
     *     console.log(event.accuracy);
     * });
     *
     * ```
     *
     */
    startCompass(options?: StartCompassOptions): Promise<void>;
    /**
     * 停止监听罗盘数据变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.startCompass();
     * ks.onCompassChange((event) => {
     *     console.log(event.direction);
     *     console.log(event.accuracy);
     * });
     *
     * setTimeout(async () => {
     *     await ks.stopCompass();
     * }, 3000);
     *
     * ```
     *
     */
    stopCompass(options?: StopCompassOptions): Promise<void>;
    /**
     * 监听罗盘数据变化事件。
     * @param callback 罗盘数据变化事件的回调函数
     *
     * @example
     * ```javascript
     * await ks.startCompass();
     * ks.onCompassChange((event) => {
     *     console.log(event.direction);
     *     console.log(event.accuracy);
     * });
     *
     * ```
     *
     */
    onCompassChange(callback: (event: CompassChangeEvent) => void): void;
    /**
     * 取消监听罗盘数据变化事件。不传入 `callback` 则取消所有监听。
     * @param callback 罗盘数据变化事件的回调函数
     *
     * @example
     * ```javascript
     * await ks.startCompass();
     *
     * function handleCompassChange(event) {
     *     console.log(event.direction);
     *     console.log(event.accuracy);
     * }
     * ks.onCompassChange(handleCompassChange);
     *
     * setTimeout(async () => {
     *     ks.offCompassChange();
     *     await ks.stopCompass();
     * }, 3000);
     *
     * ```
     *
     */
    offCompassChange(callback?: (event: CompassChangeEvent) => void): void;
}
