export interface DeviceMotionChangeEvent {
    /**
     * 设备坐标系中，z 轴垂直屏幕表面或键盘，远离屏幕的方向为正。围绕 z 轴旋转设备，将使 alpha 值发生变化。
     *
     * alpha 为 0 时表示设备顶部指向地球北极方向。当设备向左旋转时，alpha 值增大。
     *
     * 范围 [0, 2 * Math.PI) (rad)
     */
    alpha: number;
    /**
     * 设备坐标系中，x 轴沿着屏幕表面，向右为正，向左为负。围绕 x 轴前后旋转设备，将使 beta 值发生变化。
     *
     * beta 为 0 时表示设备顶部和底部与地面的距离相等。当设备向前翻转时，beta 值增大，向后翻转时，beta 值减小。
     *
     * 范围 [-Math.PI, Math.PI) (rad)
     */
    beta: number;
    /**
     * 设备坐标系中，y 轴沿着屏幕表面，向上为正，向下为负。围绕 y 轴左右倾斜设备，将使 gamma 值发生变化。
     *
     * gamma 为 0 时表示设备左右两边与地面的距离相等。当设备向右倾斜时，gamma 值增大，向左倾斜时，gamma 值减小。
     *
     * 范围 [-Math.PI / 2, Math.PI / 2) (rad)
     */
    gamma: number;
}
