import { DeviceMotionChangeEvent } from "./DeviceMotionChangeEvent";
import { StartDeviceMotionOptions } from "./StartDeviceMotionOptions";
import { StopDeviceMotionOptions } from "./StopDeviceMotionOptions";
export declare class DeviceMotionAPI {
    /**
     * 开始监听设备方向变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.startDeviceMotionListening();
     * ks.onDeviceMotionChange((event) => {
     *     //
     * });
     *
     * setTimeout(async () => {
     *     ks.offDeviceMotionChange();
     *     await ks.stopDeviceMotionListening();
     * }, 3000);
     *
     * ```
     *
     */
    startDeviceMotionListening(options?: StartDeviceMotionOptions): Promise<void>;
    /**
     * 停止监听设备方向变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.stopDeviceMotionListening();
     *
     * ```
     *
     */
    stopDeviceMotionListening(options?: StopDeviceMotionOptions): Promise<void>;
    /**
     * 监听设备方向变化事件。
     * @param callback 设备方向变化事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onDeviceMotionChange((event) => {
     *     //
     * });
     *
     * ```
     *
     */
    onDeviceMotionChange(callback: (event: DeviceMotionChangeEvent) => void): void;
    /**
     * 取消监听设备方向变化事件。不传入 `callback` 则取消所有监听。
     * @param callback 设备方向变化事件的回调函数
     *
     * @example
     * ```javascript
     * ks.offDeviceMotionChange();
     *
     * ```
     *
     */
    offDeviceMotionChange(callback?: (event: DeviceMotionChangeEvent) => void): void;
}
