import { GyroscopeChangeEvent } from "./GyroscopeChangeEvent";
import { StartGyroscopeOptions } from "./StartGyroscopeOptions";
import { StopGyroscopeOptions } from "./StopGyroscopeOptions";
export declare class GyroscopeAPI {
    /**
     * 开始监听陀螺仪数据变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.startGyroscope();
     * ks.onGyroscopeChange((event) => {
     *     //
     * });
     *
     * setTimeout(async () => {
     *     ks.offGyroscopeChange();
     *     await ks.stopGyroscope();
     * }, 3000);
     *
     * ```
     *
     */
    startGyroscope(options?: StartGyroscopeOptions): Promise<void>;
    /**
     * 停止监听陀螺仪数据变化事件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.stopGyroscope();
     *
     * ```
     *
     */
    stopGyroscope(options?: StopGyroscopeOptions): Promise<void>;
    /**
     * 监听陀螺仪数据变化事件。
     * @param callback 陀螺仪数据变化事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onGyroscopeChange((event) => {
     *     //
     * });
     *
     * ```
     *
     */
    onGyroscopeChange(callback: (event: GyroscopeChangeEvent) => void): void;
    /**
     * 取消监听陀螺仪数据变化事件。不传入 `callback` 则取消所有监听。
     * @param callback 陀螺仪数据变化事件的回调函数
     *
     * @example
     * ```javascript
     * ks.offGyroscopeChange();
     *
     * ```
     *
     */
    offGyroscopeChange(callback?: (event: GyroscopeChangeEvent) => void): void;
}
