import { GetNetworkTypeOptions } from "./GetNetworkTypeOptions";
import { GetNetworkTypeResult } from "./GetNetworkTypeResult";
import { NetworkStatusChangeEvent } from "./NetworkStatusChangeEvent";
export declare class NetworkAPI {
    /**
     * 获取网络类型。
     * @param options
     * @returns
     * @example
     * ```javascript
     * const { networkType } = await ks.getNetworkType();
     *
     * ```
     *
     */
    getNetworkType(options?: GetNetworkTypeOptions): Promise<GetNetworkTypeResult>;
    /**
     * 监听网络状态变化事件。
     * @param callback 网络状态变化事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onNetworkStatusChange((event) => {
     *     if (!event.isConnected) {
     *         ks.showToast({
     *             title: '网络已断开',
     *         });
     *     }
     * });
     *
     * ```
     *
     */
    onNetworkStatusChange(callback: (event: NetworkStatusChangeEvent) => void): void;
    /**
     * 取消监听网络状态变化事件。不传入 `callback` 则取消所有监听。
     * @param callback 网络状态变化事件的回调函数
     *
     * @example
     * ```javascript
     * ks.offNetworkStatusChange();
     *
     * ```
     *
     */
    offNetworkStatusChange(callback?: (event: NetworkStatusChangeEvent) => void): void;
}
