import { Component, Page } from "../common";
import { IntersectionObserver, IntersectionObserverOptions } from "./IntersectionObserver";
import { SelectorQuery } from "./SelectorQuery";
export declare class KSMLAPI {
    /**
     * 创建并返回一个 `IntersectionObserver` 对象实例。在自定义组件或包含自定义组件的页面中，应使用 `this.createIntersectionObserver([options])` 来代替。
     * @version {"kma":"1.1.0","ide":"1.22.0"}
     * @param component 自定义组件实例
     * @param options
     * @returns
     * @example
     * ```javascript
     * Page({
     *     observer: null,
     *     onLoad() {
     *         this.observer = ks.createIntersectionObserver(this);
     *         this.observer.relativeTo('.scroll-view').observe('.b', (res) => {
     *             if (res.intersectionRatio < 0) {
     *                 console.log('b 不在滚动可视区域内');
     *             }
     *         });
     *     },
     *     onUnload() {
     *         if (this.observer) {
     *             this.observer.disconnect();
     *         }
     *     },
     * });
     *
     * ```
     *
     */
    createIntersectionObserver(component?: Component | Page, options?: IntersectionObserverOptions): IntersectionObserver;
    /**
     * 返回一个 `SelectorQuery` 对象实例。在自定义组件或包含自定义组件的页面中，应使用 `this.createSelectorQuery()` 来代替。
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @returns
     * @example
     * ```javascript
     * const query = ks.createSelectorQuery();
     * query.select('#the-id').boundingClientRect();
     * query.selectViewport().scrollOffset();
     * query.exec((res) => {
     *     const top = res[0].top; // #the-id节点的上边界坐标
     *     const scrollTop = res[1].scrollTop; // 显示区域的竖直滚动位置
     * });
     *
     * ```
     *
     */
    createSelectorQuery(): SelectorQuery;
}
