import { GetCenterLocationOptions } from "./GetCenterLocationOptions";
import { GetRegionOptions } from "./GetRegionOptions";
import { GetScaleOptions } from "./GetScaleOptions";
import { MoveToLocationOptions } from "./MoveToLocationOptions";
import { IncludePointsOptions } from "./IncludePointsOptions";
import { OpenMapAppOptions } from "./OpenMapAppOptions";
import { LngLat } from "./LngLat";
import { GetRegionOptionsSucRes } from "./GetRegionOptionsSucRes";
import { GetScaleSucRes } from "./GetScaleSucRes";
/**
 *地图上下文。通过 ks.createMapContext 获取的实例，通过它能够操作地图。
 */
export interface MapContext {
    nodeId?: number;
    /**
     * 获取当前地图中心的经纬度，返回的是 gcj02 坐标系
     */
    getCenterLocation(options?: GetCenterLocationOptions): Promise<LngLat>;
    /**
     * 获取地图视野范围。
     */
    getRegion(options?: GetRegionOptions): Promise<GetRegionOptionsSucRes>;
    /**
     * 获取地图缩放值。
     */
    getScale(options?: GetScaleOptions): Promise<GetScaleSucRes>;
    /**
     * 将地图中心移动到定位点。地图能力基于 gcj02 坐标系，请注意入参的经纬度信息转换。
     * @param options
     */
    moveToLocation(options?: MoveToLocationOptions): Promise<void>;
    /**
     * 缩放视野展示所有经纬度。
     * @param options
     */
    includePoints(options: IncludePointsOptions): Promise<void>;
    /**
     * 拉起地图 APP选择导航。基础库1.41.0开始支持。
     * @param options
     */
    openMapApp(options: OpenMapAppOptions): Promise<void>;
}
