import { InnerAudioContext } from "./InnerAudioContext";
import { InnerAudioOptions } from "./InnerAudioOptions";
export declare class AudioAPI {
    /**
     * 创建音频上下文对象。
     * @returns 音频上下文对象
     *
     * @example
     * ```javascript
     * const innerAudioContext = ks.createInnerAudioContext();
     *
     * innerAudioContext.src =
     *     'https://static.yximgs.com/udata/pkg/miniprogram-outer/test.m4a';
     *
     * innerAudioContext.play();
     *
     * ```
     *
     */
    createInnerAudioContext(): InnerAudioContext;
    /**
     * 全局设置 `InnerAudioContext` 的播放选项。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.setInnerAudioOption({
     *     mixWithOther: true,
     *     obeyMuteSwitch: true,
     *     success() {
     *         console.log('设置播放选项成功');
     *     },
     *     fail() {
     *         console.log('设置播放选项失败');
     *     },
     * });
     *
     * ```
     *
     */
    setInnerAudioOption(options?: InnerAudioOptions): Promise<void>;
    /**
     * 监听音频因为受到系统占用而被中断开始事件。以下场景会触发此事件：闹钟。此事件触发后，小程序内所有音频会暂停。
     * @param callback 音频因为受到系统占用而被中断开始事件的回调函数
     */
    onAudioInterruptionBegin(callback: () => void): void;
    /**
     * 取消监听音频因为受到系统占用而被中断开始事件。
     * @param callback 音频因为受到系统占用而被中断开始事件的回调函数
     */
    offAudioInterruptionBegin(callback?: () => void): void;
    /**
     * 监听音频中断结束事件。在收到 `onAudioInterruptionBegin` 事件之后，小程序内所有音频会暂停，收到此事件之后才可再次播放成功。
     * @param callback 音频中断结束事件的回调函数
     */
    onAudioInterruptionEnd(callback: () => void): void;
    /**
     * 取消监听音频中断结束事件。
     * @param callback 音频中断结束事件的回调函数
     */
    offAudioInterruptionEnd(callback?: () => void): void;
}
