import { ChooseImageOptions } from "./ChooseImageOptions";
import { ChooseImageResult } from "./ChooseImageResult";
import { CompressImageOptions } from "./CompressImageOptions";
import { CompressImageResult } from "./CompressImageResult";
import { GetImageInfoOptions } from "./GetImageInfoOptions";
import { ImageInfo } from "./ImageInfo";
import { PreviewImageOptions } from "./PreviewImageOptions";
import { SaveImageToPhotosAlbumOptions } from "./SaveImageToPhotosAlbumOptions";
export declare class ImageAPI {
    /**
     * 从本地相册选择图片，或使用相机拍摄图片。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const { tempFiles } = await ks.chooseImage({
     *     sizeType: 'compressed',
     *     sourceType: 'album',
     *     count: 5,
     * });
     *
     * ```
     *
     */
    chooseImage(options?: ChooseImageOptions): Promise<ChooseImageResult>;
    /**
     * 压缩图片。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const { tempFilePath } = await ks.compressImage({
     *     src: 'path/to/image',
     *     quality: 80,
     * });
     *
     * ```
     *
     */
    compressImage(options: CompressImageOptions): Promise<CompressImageResult>;
    /**
     * 获取图片信息。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const imageInfo = await ks.getImageInfo({
     *     src: 'path/to/image',
     * });
     *
     * ```
     *
     */
    getImageInfo(options: GetImageInfoOptions): Promise<ImageInfo>;
    /**
     * 在新页面中全屏预览图片。预览的过程中用户可以进行保存图片操作。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.previewImage({
     *     urls: ['path/to/images'],
     * });
     *
     * ```
     *
     */
    previewImage(options: PreviewImageOptions): Promise<void>;
    /**
     * 保存图片到系统相册。调用前需要 [用户授权](https://open.kuaishou.com/docs/develop/api-next/open/authorize/ks.authorize) `scope.writePhotosAlbum`。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.saveImageToPhotosAlbum({
     *     filePath: 'path/to/image',
     * });
     *
     * ```
     *
     */
    saveImageToPhotosAlbum(options: SaveImageToPhotosAlbumOptions): Promise<void>;
}
