import { RecorderErrorEvent } from "./RecorderErrorEvent";
import { RecorderStartOptions } from "./RecorderStartOptions";
import { RecorderStopEvent } from "./RecorderStopEvent";
/**
 * 录音管理器。
 */
export interface RecorderManager {
    /**
     * 监听录音出错事件。
     * @param callback 录音出错事件的回调函数
     * @alpha
     */
    onError(callback: (event: RecorderErrorEvent) => void): void;
    /**
     * 停止监听录音出错事件。
     * @param callback 停止监听录音出错事件的回调函数
     * @alpha
     */
    offError(callback?: (event: RecorderErrorEvent) => void): void;
    /**
     * 监听录音结束事件。
     * @param callback 录音结束事件的回调函数
     * @alpha
     */
    onStop(callback: (event: RecorderStopEvent) => void): void;
    /**
     * 停止监听录音结束事件。
     * @param callback 停止监听录音结束事件的回调函数
     * @alpha
     */
    offStop(callback?: (event: RecorderStopEvent) => void): void;
    /**
     * 开始录音。
     * @param options
     * @alpha
     */
    start(options?: RecorderStartOptions): void;
    /**
     * 结束录音。
     * @alpha
     */
    stop(): void;
}
