import { APIFullError } from "../../common";
import { ChooseMediaResult } from "./ChooseMediaResult";
declare const chooseMediaSourceTypes: readonly [
    "album",
    "camera"
];
declare type ChooseMediaSourceType = typeof chooseMediaSourceTypes[number];
declare const chooseMediaCameras: readonly [
    "back",
    "front"
];
/**
 * @value 'back' 使用后置摄像头
 * @value 'front' 使用前置摄像头
 */
declare type ChooseMediaCamera = typeof chooseMediaCameras[number];
declare const chooseMediaTypes: readonly [
    "image",
    "video"
];
declare type ChooseMediaType = typeof chooseMediaTypes[number];
declare const chooseMediaSizeTypes: readonly [
    "original",
    "compressed"
];
declare type ChooseMediaSizeType = typeof chooseMediaSizeTypes[number];
declare type ChooseMediaCallbackOptions = import("../../common").CallbackOptions<ChooseMediaResult, APIFullError>;
export interface ChooseMediaOptions extends ChooseMediaCallbackOptions {
    /**
     * 最多可以选择的文件个数，最多可支持20个文件
     */
    count?: number;
    /**
     * 文件类型
     * @defaultValue ['image', 'video']
     * @value 'image' 只能拍摄图片或从相册选择图片
     * @value 'video' 只能拍摄视频或从相册选择视频
     */
    mediaType?: ChooseMediaType[];
    /**
     * 图片和视频选择的来源
     * @defaultValue ['album', 'camera']
     * @value 'album' 从相册选择
     * @value 'camera' 使用相机拍摄
     */
    sourceType?: ChooseMediaSourceType[];
    /**
     * 拍摄视频最长拍摄时间，单位秒。时间范围为 3s 至 60s 之间。不限制相册
     */
    maxDuration?: number;
    /**
     * 是否压缩所选文件
     * @defaultValue ['original', 'compressed']
     * @value 'original' 原图
     * @value 'compressed' 压缩
     */
    sizeType?: ChooseMediaSizeType[];
    /**
     * 仅在 sourceType 为 camera 时生效，使用前置或后置摄像头
     */
    camera?: ChooseMediaCamera;
}
export {};
