import { VideoRequestFullScreenOptions } from "./VideoRequestFullScreenOptions";
declare const videoPlaybackRates: readonly [
    0.5,
    0.8,
    1,
    1.25,
    1.5,
    2
];
declare type VideoPlaybackRate = typeof videoPlaybackRates[number];
/**
 * 视频上下文。
 */
export interface VideoContext {
    nodeId?: number;
    /**
     * 退出全屏。
     */
    exitFullScreen(): void;
    /**
     * 隐藏状态栏。（仅在 iOS 上全屏时生效）
     */
    hideStatusBar(): void;
    /**
     * 暂停播放视频。
     */
    pause(): void;
    /**
     * 开始播放视频。
     */
    play(): void;
    /**
     * 设置播放倍率。
     * @param rate 播放倍率
     */
    playbackRate(rate: VideoPlaybackRate): void;
    /**
     * 进入全屏。（同层渲染模式下Android不支持设置全屏方向，默认为 90）
     * @param options
     */
    requestFullScreen(options?: VideoRequestFullScreenOptions): void;
    /**
     * 跳转到视频的指定位置。
     * @param position 跳转位置 (s)
     */
    seek(position: number): void;
    /**
     * 显示状态栏。（仅在 iOS 上全屏时生效）
     */
    showStatusBar(): void;
    /**
     * 停止播放视频。
     */
    stop(): void;
}
export {};
