import { DownloadFileOptions } from "./DownloadFileOptions";
import { DownloadTask } from "./DownloadTask";
export declare class DownloadAPI {
    /**
     * 下载文件资源到本地。客户端直接发起一个 HTTPS GET 请求，返回文件的本地临时路径 (本地路径)，单次下载允许的最大文件为 50MB
     *
     * 注意：请在服务端响应的 header 中指定合理的 `Content-Type` 字段，以保证客户端正确处理文件类型。
     * @param options
     * @returns 一个可以监听下载进度变化事件和取消下载的对象
     *
     * @example
     * ```javascript
     * ks.downloadFile({
     *     url: 'https://example.com/',
     *     success(res) {
     *         // 只要服务器有响应数据，就会把响应内容写入文件并进入 success 回调，业务需要自行判断是否下载到了想要的内容
     *         if (res.statusCode === 200) {
     *             const { tempFilePath } = res;
     *         }
     *     },
     * });
     *
     * ```
     *
     */
    downloadFile(options: DownloadFileOptions): DownloadTask;
}
