import { ConnectSocketOptions } from "./ConnectSocketOptions";
import { SocketCloseEvent } from "./SocketCloseEvent";
import { SocketCloseOptions } from "./SocketCloseOptions";
import { SocketErrorEvent } from "./SocketErrorEvent";
import { SocketMessageEvent } from "./SocketMessageEvent";
import { SocketOpenEvent } from "./SocketOpenEvent";
import { SocketSendOptions } from "./SocketSendOptions";
import { SocketTask } from "./SocketTask";
export declare class WebSocketAPI {
    /**
     * 通过 WebSocket 连接发送数据。需要先 `ks.connectSocket`，并在 `ks.onSocketOpen` 回调之后才能发送。
     * @deprecated 本接口停止维护，请使用 `SocketTask.send` 代替
     */
    sendSocketMessage(options: SocketSendOptions): Promise<void>;
    /**
     * 监听 WebSocket 连接打开事件。
     * @param callback WebSocket 连接打开事件的回调函数
     * @deprecated 本接口停止维护，请使用 `SocketTask.onOpen` 代替
     */
    onSocketOpen(callback: (event: SocketOpenEvent) => void): void;
    /**
     * 监听 WebSocket 接受到服务器的消息事件。
     * @param callback WebSocket 接受到服务器的消息事件的回调函数
     * @deprecated 本接口停止维护，请使用 `SocketTask.onMessage` 代替
     */
    onSocketMessage(callback: (event: SocketMessageEvent) => void): void;
    /**
     * 监听 WebSocket 错误事件。
     * @param callback WebSocket 错误事件的回调函数
     * @deprecated 本接口停止维护，请使用 `SocketTask.onError` 代替
     */
    onSocketError(callback: (event: SocketErrorEvent) => void): void;
    /**
     * 监听 WebSocket 连接关闭事件。
     * @param callback WebSocket 连接关闭事件的回调函数
     * @deprecated 本接口停止维护，请使用 `SocketTask.onClose` 代替
     */
    onSocketClose(callback: (event: SocketCloseEvent) => void): void;
    /**
     * 创建一个 WebSocket 连接。
     * @param options
     * @returns SocketTask 实例
     *
     * @example
     * ```javascript
     * const ws = ks.connectSocket({
     *     url: 'wss://example.com',
     *     header: {
     *         'content-type': 'application/json',
     *     },
     *     protocols: ['protocol1'],
     * });
     *
     * ws.onMessage((event) => {
     *     const { data } = event;
     *     console.log('接受到数据', data);
     *     ws.close();
     * });
     *
     * ws.send({ data: 'data' });
     *
     * ```
     *
     */
    connectSocket(options: ConnectSocketOptions): SocketTask;
    /**
     * 关闭 WebSocket 连接。
     * @deprecated 本接口停止维护，请使用 `SocketTask.close` 代替
     */
    closeSocket(options?: SocketCloseOptions): Promise<void>;
}
