import { RequestSubscribeMessageOptions } from "./RequestSubscribeMessageOptions";
export declare class SubscribeMessageAPI {
    /**
     * 调起客户端小程序订阅消息界面，获取用户订阅消息的操作结果。[完整订阅能力接入](https://open.kuaishou.com/docs/develop/functionAccessGuide/message.html)
     * @version {"kma":"1.26.1","ide":"1.22.0__MOCK"}
     * @param options
     * @returns
     * @errinfo [{"errMsg":"repeated request","errDesc":"重复订阅"},{"errMsg":"empty template id","errDesc":"模板id参数为空"},{"errMsg":"template number exceed limit","errDesc":"模板消息数量超过限制"},{"errMsg":"user close main switch","errDesc":"用户关闭了总开关，无法弹窗"},{"errMsg":"template type not unified","errDesc":"模板消息类型不统一，必须全部为一次性消息或永久消息"}]
     *
     * @example
     * ```javascript
     * const res = await ks.requestSubscribeMessage({
     *     tmplIds: ['YOUR_TEMPLATE_ID'],
     * });
     *
     * if (res.YOUR_TEMPLATE_ID === 'ACCEPT') {
     *     // 用户同意订阅消息
     * } else {
     *     // 用户拒绝订阅消息
     * }
     *
     * ```
     *
     */
    requestSubscribeMessage(options: RequestSubscribeMessageOptions): Promise<Record<string, 'ACCEPT' | 'REFUSE'>>;
}
