import { GetUserInfoOptions } from "./GetUserInfoOptions";
import { UserInfoResult } from "./UserInfoResult";
import { AuthorizedUserInfoResult } from "./AuthorizedUserInfoResult";
export declare class UserInfoAPI {
    /**
     * 获取用户信息。调用前需要 [用户授权](https://open.kuaishou.com/docs/develop/api-next/open/authorize/ks.authorize) `scope.userInfo`。
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @param options
     *
     * @returns #### 敏感数据解密后结构示例
     * ```javascript
     * {
     *     "gender": "gender", // 性别 0：未知、1：男、2：女
     *     "avatarUrl": "AVATARURL",
     *     "nickName": "NICKNAME",
     *     "openId": "OPENID",
     * }
     * ```
     *
     * @errinfo [{"errMsg":"auth deny","errDesc":"用户拒绝授权"},{"errMsg":"Invalid app","errDesc":"应用不存在"},{"errMsg":"beyond token/app/authorized scope","errDesc":"请求被拒绝，可能是无效token或应用/用户不允许访问该接口"},{"errMsg":"not exist user","errDesc":"用户信息不存在"},{"errMsg":"invalid scope","errDesc":"请求授权的scope错误"}]
     *
     */
    getUserInfo(options?: GetUserInfoOptions): Promise<UserInfoResult | AuthorizedUserInfoResult>;
}
