import type { Mixins } from "../common";
import { AnimationAPI } from "./animation";
import { BackgroundAPI } from "./background";
import { InteractionAPI } from "./interaction";
import { KeyboardAPI } from "./keyboard";
import { MenuAPI } from "./menu";
import { NavigationBarAPI } from "./navigation-bar";
import { PullDownRefreshAPI } from "./pull-down-refresh";
import { ScrollAPI } from "./scroll";
import { TabBarAPI } from "./tab-bar";
import { WindowAPI } from "./window";
declare const UIAPIs: readonly [
    typeof AnimationAPI,
    typeof BackgroundAPI,
    typeof InteractionAPI,
    typeof KeyboardAPI,
    typeof MenuAPI,
    typeof NavigationBarAPI,
    typeof PullDownRefreshAPI,
    typeof ScrollAPI,
    typeof TabBarAPI,
    typeof WindowAPI
];
export declare class UIAPI {
    /**
     * 延迟一部分操作到下一个时间片再执行。（类似于 setTimeout）
     * @param callback
     * @example
     * ```javascript
     * Component({
     *     data: {
     *         number: 0,
     *     },
     *     doSth() {
     *         this.setData({
     *             number: 1,
     *         }); // 直接在当前同步流程中执行
     *
     *         ks.nextTick(() => {
     *             this.setData({
     *                 number: 3,
     *             }); // 在当前同步流程结束后，下一个时间片执行
     *         });
     *
     *         this.setData({
     *             number: 2,
     *         }); // 直接在当前同步流程中执行
     *     },
     * });
     *
     * ```
     *
     */
    nextTick(callback: () => void): void;
}
export interface UIAPI extends Mixins<typeof UIAPIs> {
}
export {};
