import { HideNavigationBarLoadingOptions } from "./HideNavigationBarLoadingOptions";
import { SetNavigationBarColorOptions } from "./SetNavigationBarColorOptions";
import { SetNavigationBarTitleOptions } from "./SetNavigationBarTitleOptions";
import { ShowNavigationBarLoadingOptions } from "./ShowNavigationBarLoading";
export declare class NavigationBarAPI {
    /**
     * 设置页面导航条颜色。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.setNavigationBarColor({
     *     frontColor: '#ffffff',
     *     backgroundColor: '#ff0000',
     *     animation: {
     *         duration: 400,
     *         timingFunc: 'easeIn',
     *     },
     * });
     *
     * ```
     *
     */
    setNavigationBarColor(options: SetNavigationBarColorOptions): Promise<void>;
    /**
     * 动态设置当前页面的标题。
     * @param options
     * @returns
     * @example
     * ```javascript
     * ks.setNavigationBarTitle({
     *     title: '当前页面',
     * });
     *
     * ```
     *
     */
    setNavigationBarTitle(options: SetNavigationBarTitleOptions): Promise<void>;
    /**
     * 在当前页面显示导航条加载动画。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.showNavigationBarLoading();
     *
     * setTimeout(() => {
     *     ks.hideNavigationBarLoading();
     * }, 1000);
     *
     * ```
     *
     */
    showNavigationBarLoading(options?: ShowNavigationBarLoadingOptions): Promise<void>;
    /**
     * 在当前页面隐藏导航条加载动画。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.showNavigationBarLoading();
     *
     * setTimeout(() => {
     *     ks.hideNavigationBarLoading();
     * }, 1000);
     *
     * ```
     *
     */
    hideNavigationBarLoading(options?: HideNavigationBarLoadingOptions): Promise<void>;
}
