import { SetTabBarBadgeOptions } from "./SetTabBarBadgeOptions";
import { SetTabBarItemOptions } from "./SetTabBarItemOptions";
import { SetTabBarStyleOptions } from "./SetTabBarStyleOptions";
import { TabBarItemOptions } from "./TabBarItemOptions";
import { TabBarOptions } from "./TabBarOptions";
export declare class TabBarAPI {
    /**
     * 为 tabBar 某一项的右上角添加文本。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.setTabBarBadge({
     *     index: 0,
     *     text: '1',
     * });
     *
     * ```
     *
     */
    setTabBarBadge(options: SetTabBarBadgeOptions): Promise<void>;
    /**
     * 移除 tabBar 某一项右上角的文本。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.removeTabBarBadge({
     *     index: 0,
     * });
     *
     * ```
     *
     */
    removeTabBarBadge(options: TabBarItemOptions): Promise<void>;
    /**
     * 动态设置 tabBar 某一项的内容，图片支持临时文件。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.setTabBarItem({
     *     index: 0,
     *     text: 'text',
     *     iconPath: '/path/to/iconPath',
     *     selectedIconPath: '/path/to/selectedIconPath',
     * });
     *
     * ```
     *
     */
    setTabBarItem(options: SetTabBarItemOptions): Promise<void>;
    /**
     * 动态设置 tabBar 的整体样式。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.setTabBarStyle({
     *     color: '#FF0000',
     *     selectedColor: '#00FF00',
     *     backgroundColor: '#0000FF',
     *     borderStyle: 'white',
     * });
     *
     * ```
     *
     */
    setTabBarStyle(options: SetTabBarStyleOptions): Promise<void>;
    /**
     * 显示 tabBar。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.showTabBar({ animation: true });
     *
     * ```
     *
     */
    showTabBar(options?: TabBarOptions): Promise<void>;
    /**
     * 隐藏 tabBar。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.hideTabBar();
     *
     * ```
     *
     */
    hideTabBar(options?: TabBarOptions): Promise<void>;
    /**
     * 显示 tabBar 某一项的右上角的红点。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.showTabBarRedDot({
     *     index: 0,
     * });
     *
     * ```
     *
     */
    showTabBarRedDot(options: TabBarItemOptions): Promise<void>;
    /**
     * 隐藏 tabBar 某一项的右上角的红点。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.hideTabBarRedDot({
     *     index: 0,
     * });
     *
     * ```
     *
     */
    hideTabBarRedDot(options: TabBarItemOptions): Promise<void>;
}
