import type { CustomEvent } from "../../constructors/events";
/**
 * 画布。
 *
 * @version {"kma":"1.26.1","ide":"1.22.0"}
 */
export declare interface CanvasProps {
    /**
     * canvas 组件的唯一标识符
     */
    canvasId?: string;
    /**
     * 指定 canvas 类型，目前只支持 2d
     * @alpha
     */
    type?: '2d' | 'webgl';
    /**
     * 当在 canvas 中移动时且有绑定手势事件时，禁止屏幕滚动以及下拉刷新
     * @alpha
     */
    disableScroll?: boolean;
    /**
     * 手指触摸动作开始
     */
    onCanvasTouchStart?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 手指触摸后移动
     */
    onCanvasTouchMove?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 手指触摸动作结束
     */
    onCanvasTouchEnd?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 手指触摸动作被打断，如来电提醒，弹窗
     */
    onCanvasTouchCancel?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 手指长按 500ms 之后触发，触发了长按事件后进行移动不会触发屏幕的滚动
     * @alpha
     */
    onCanvasLongTap?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 当发生错误时触发 error 事件，detail = {errMsg}
     * @alpha
     */
    onCanvasError?: (event: CustomEvent<Record<string, unknown>>) => void;
}
