import type { CustomEvent } from "../../constructors/events";
import { BaseProps } from "../props";
declare const imageMode: readonly [
    "scaleToFill",
    "aspectFit",
    "aspectFill",
    "widthFix",
    "heightFix",
    "top",
    "bottom",
    "center",
    "left",
    "right",
    "top left",
    "top right",
    "bottom left",
    "bottom right"
];
/**
 * @value 'scaleToFill' 缩放模式，不保持纵横比缩放图片，使图片的宽高完全拉伸至填满 image 元素
 * @value 'aspectFit' 缩放模式，保持纵横比缩放图片，使图片的长边能完全显示出来。也就是说，可以完整地将图片显示出来
 * @value 'aspectFill' 缩放模式，保持纵横比缩放图片，只保证图片的短边能完全显示出来。也就是说，图片通常只在水平或垂直方向是完整的，另一个方向将会发生截取
 * @value 'widthFix' 缩放模式，宽度不变，高度自动变化，保持原图宽高比不变
 * @value 'heightFix' 缩放模式，高度不变，宽度自动变化，保持原图宽高比不变
 * @value 'top' 裁剪模式，不缩放图片，只显示图片的顶部区域
 * @value 'bottom' 裁剪模式，不缩放图片，只显示图片的底部区域
 * @value 'center' 裁剪模式，不缩放图片，只显示图片的中间区域
 * @value 'left' 裁剪模式，不缩放图片，只显示图片的左边区域
 * @value 'right' 裁剪模式，不缩放图片，只显示图片的右边区域
 * @value 'top left' 裁剪模式，不缩放图片，只显示图片的左上边区域
 * @value 'top right' 裁剪模式，不缩放图片，只显示图片的右上边区域
 * @value 'bottom left' 裁剪模式，不缩放图片，只显示图片的左下边区域
 * @value 'bottom right' 裁剪模式，不缩放图片，只显示图片的右下边区域
 */
declare type ImageMode = typeof imageMode[number];
/**
 * 图片。支持 JPG、PNG、SVG、GIF 等格式。
 *
 * @version {"kma":"1.1.0","ide":"1.22.0"}
 *
 */
export declare interface ImageProps extends BaseProps {
    /**
     * 图片资源地址
     */
    src?: string;
    /**
     * 图片裁剪、缩放的模式
     */
    mode?: ImageMode;
    /**
     * 图片懒加载，在即将进入一定范围（上下三屏）时才开始加载
     */
    lazyLoad?: boolean;
    /**
     * 当错误发生时触发，event.detail = {errMsg}
     */
    onError?: (event: CustomEvent<{
        errMsg: string;
    }>) => void;
    /**
     * 当图片载入完毕时触发，event.detail = {height, width}
     */
    onLoad?: (event: CustomEvent<{
        height: number;
        width: number;
    }>) => void;
}
export {};
