import type { CustomEvent } from "../../constructors/events";
declare const direction: readonly [
    "all",
    "vertical",
    "horizontal",
    "none"
];
/**
 * 可移动的视图容器，在页面中可以拖拽滑动。movable-view 必须在 movable-area 组件中，并且必须是直接子节点，否则不能移动。
 *
 * @version {"kma":"1.1.0","ide":"1.22.0"}
 *
 */
export declare interface MovableViewProps {
    /**
     * movable-view 的移动方向，属性值有 all、vertical、horizontal、none
     */
    direction?: typeof direction[number];
    /**
     * movable-view 是否带有惯性
     * @alpha
     */
    inertia?: boolean;
    /**
     * 超过可移动区域后，movable-view 是否还可以移动
     */
    outOfBounds?: boolean;
    /**
     * 定义 x 轴方向的偏移，如果x的值不在可移动范围内，会自动移动到可移动范围；改变 x 的值会触发动画；单位支持 px（默认）、rpx
     */
    x?: number;
    /**
     * 定义 y 轴方向的偏移，如果y的值不在可移动范围内，会自动移动到可移动范围；改变 y 的值会触发动画；单位支持 px（默认）、rpx
     */
    y?: number;
    /**
     * 阻尼系数，用于控制 x 或 y 改变时的动画和过界回弹的动画，值越大移动越快
     * @alpha
     */
    damping?: number;
    /**
     * 摩擦系数，用于控制惯性滑动的动画，值越大摩擦力越大，滑动越快停止；必须大于 0，否则会被设置成默认值
     * @alpha
     */
    friction?: number;
    /**
     * 是否禁用
     */
    disabled?: boolean;
    /**
     * 是否支持双指缩放，默认缩放手势生效区域是在 movable-view 内
     */
    scale?: boolean;
    /**
     * 定义缩放倍数最小值
     */
    scaleMin?: number;
    /**
     * 定义缩放倍数最大值
     */
    scaleMax?: number;
    /**
     * 定义缩放倍数，取值范围为 0.5 - 10
     */
    scaleValue?: number;
    /**
     * 是否使用动画
     */
    animation?: boolean;
    /**
     * 拖动过程中触发的事件，event.detail = {x, y, source}
     */
    onChange?: (event: CustomEvent<{
        x: number;
        y: number;
        source: string;
    }>) => void;
    /**
     * 缩放过程中触发的事件，event.detail = {x, y, scale}
     */
    onScale?: (event: CustomEvent<{
        x: number;
        y: number;
        scale: number;
    }>) => void;
}
export {};
