declare const colorAnimationTimingFunc: readonly [
    "linear",
    "easeIn",
    "easeOut",
    "easeInOut"
];
/**
 * 页面导航条配置节点，用于指定导航栏的一些属性。只能是 [page-meta](https://open.kuaishou.com/docs/develop/components/base/page-meta.html) 组件内的第一个节点，需要配合它一同使用。
 * 通过这个节点可以获得类似于调用 [ks.setNavigationBarTitle](https://open.kuaishou.com/docs/develop/api-next/ui/navigation-bar/ks.setNavigationBarTitle.html) [ks.setNavigationBarColor](https://open.kuaishou.com/docs/develop/api-next/ui/navigation-bar/ks.setNavigationBarColor.html) 等接口调用的效果。
 *
 * @version {"kma":"1.2.0","ide":"1.22.0"}
 */
export declare interface NavigationBarProps {
    /**
     * 导航条标题
     */
    title?: string;
    /**
     * 是否在导航条显示 loading 加载提示
     */
    loading?: boolean;
    /**
     * 导航条前景颜色值，包括按钮、标题、状态栏的颜色，仅支持 #ffffff 和 #000000
     */
    frontColor: string;
    /**
     * 导航条背景颜色值，有效值为十六进制颜色
     */
    backgroundColor: string;
    /**
     * 改变导航栏颜色时的动画时长
     */
    colorAnimationDuration?: number;
    /**
     * 改变导航栏颜色时的动画方式，支持 linear 、 easeIn 、 easeOut 和 easeInOut
     */
    colorAnimationTimingFunc?: typeof colorAnimationTimingFunc[number];
}
export {};
