declare const navigatorTarget: readonly [
    "self",
    "miniProgram"
];
declare const navigatorOpenType: readonly [
    "navigate",
    "redirect",
    "switchTab",
    "reLaunch",
    "navigateBack",
    "exit"
];
declare const navigatorVersion: readonly [
    "develop",
    "trial",
    "release"
];
/**
 * @value 'self' 当前小程序
 * @value 'miniProgram' 其它小程序
 */
declare type NavigatorTarget = typeof navigatorTarget[number];
/**
 * @value 'navigate' 对应 ks.navigateTo 或 ks.navigateToMiniProgram 的功能
 * @value 'redirect' 对应 ks.redirectTo 的功能
 * @value 'switchTab' 对应 ks.switchTab 的功能
 * @value 'reLaunch' 对应 ks.reLaunch 的功能
 * @value 'navigateBack' 对应 ks.navigateBack 的功能
 * @value 'exit' 退出小程序，target="miniProgram" 时生效 MINIMUM__KMA__VERSION(1.44.0)
 */
declare type NavigatorOpenType = typeof navigatorOpenType[number];
/**
 * @value 'develop' 开发版
 * @value 'trial' 体验版
 * @value 'release' 正式版，仅在当前小程序为开发版或体验版时此参数有效；如果当前小程序是正式版，则打开的小程序必定是正式版
 */
declare type NavigatorVersion = typeof navigatorVersion[number];
/**
 * 页面链接。
 * @version {"kma":"1.1.0","ide":"1.22.0"}
 *
 */
export declare interface NavigatorProps {
    /**
     * 在哪个目标上发生跳转，默认当前小程序
     */
    target?: NavigatorTarget;
    /**
     * 当前小程序内的跳转链接
     */
    url?: string;
    /**
     * 跳转方式
     */
    openType?: NavigatorOpenType;
    /**
     * 当 open-type 为 'navigateBack' 时有效，表示回退的层数
     */
    delta?: number;
    /**
     * 当 target="miniProgram" 时有效，要打开的小程序 appId
     */
    appId?: string;
    /**
     * 当 target="miniProgram" 时有效，打开的页面路径，如果为空则打开首页
     */
    path?: string;
    /**
     * 当 target="miniProgram" 时有效，需要传递给目标小程序的数据，目标小程序可在 App.onLaunch()，App.onShow() 中获取到这份数据。
     */
    extraData?: Record<string | number | symbol, unknown>;
    /**
     * 当 target="miniProgram" 时有效，要打开的小程序版本
     * @alpha
     */
    version?: NavigatorVersion;
    /**
     * 指定点击时的样式类，当 hover-class="none" 时，没有点击态效果
     */
    hoverClass?: string;
    /**
     * 指定是否阻止本节点的祖先节点出现点击态
     */
    hoverStopPropagation?: boolean;
    /**
     * 按住后多久出现点击态，单位毫秒
     */
    hoverStartTime?: string | number;
    /**
     * 手指松开后点击态保留时间，单位毫秒
     */
    hoverStayTime?: string | number;
}
export {};
