/**
 * 页面属性配置节点，用于指定页面的一些属性、监听页面事件。只能是页面内的第一个节点。可以配合 navigation-bar 组件一同使用。
 * 通过这个节点可以获得类似于调用 ks.setBackgroundTextStyle ks.setBackgroundColor 等接口调用的效果。
 * @version {"kma":"1.2.0","ide":"1.22.0"}
 */
export declare interface PageMetaProps {
    /**
     * 下拉背景字体、loading 图的样式，仅支持 dark 和 light
     */
    backgroundTextStyle?: string;
    /**
     * 窗口的背景色，必须为十六进制颜色值
     */
    backgroundColor?: string;
    /**
     * 顶部窗口的背景色，必须为十六进制颜色值
     */
    backgroundColorTop?: string;
    /**
     * 底部窗口的背景色，必须为十六进制颜色值
     */
    backgroundColorBottom?: string;
    /**
     * 页面内容的背景色，用于页面中的空白部分和页面大小变化 resize 动画期间的临时空闲区域
     */
    rootBackgroundColor?: string;
    /**
     * 滚动位置，可以使用 px 或者 rpx 为单位，在被设置时，页面会滚动到对应位置
     */
    scrollTop?: string;
    /**
     * 滚动动画时长
     */
    scrollDuration?: number;
    /**
     * 页面根节点样式
     */
    pageStyle?: string;
    /**
     * 页面 page 的字体大小，可以设置为 system ，表示使用当前用户设置的快手字体大小
     */
    pageFontSize?: string;
    /**
     * 页面的根字体大小，页面中的所有 rem 单位，将使用这个字体大小作为参考值, 也可以设置为 system
     */
    rootFontSize?: string;
    /**
     * 页面的方向，可为 auto portrait 或 landscape
     * @alpha
     */
    pageOrientation?: string;
}
