import type { CustomEvent } from "../../constructors/events";
/**
 * 可滚动视图区域。使用竖向滚动时，需要给 [scroll-view](./scroll-view) 一个固定高度。组件属性的长度单位支持 rpx/px（默认为 px）
 *
 * @version {"kma":"1.2.0","ide":"1.22.0"}
 */
export declare interface ScrollViewProps {
    /**
     * 允许横向滚动
     */
    scrollX?: boolean;
    /**
     * 允许纵向滚动
     */
    scrollY?: boolean;
    /**
     * 距顶部/左边多远时，触发 scrolltoupper 事件
     */
    upperThreshold?: number | string;
    /**
     * 距底部/右边多远时，触发 scrolltolower 事件
     */
    lowerThreshold?: number | string;
    /**
     * 设置竖向滚动条位置
     */
    scrollTop?: number | string;
    /**
     * 设置横向滚动条位置
     */
    scrollLeft?: number | string;
    /**
     * 值应为某子元素 id（id不能以数字开头）。设置哪个方向可滚动，则在哪个方向滚动到该元素
     */
    scrollIntoView?: string;
    /**
     * 在设置滚动条位置时使用动画过渡
     */
    scrollWithAnimation?: boolean;
    /**
     * 滚动条显隐控制
     */
    showScrollbar?: boolean;
    /**
     * iOS 点击顶部状态栏、安卓双击标题栏时，滚动条返回顶部，只支持竖向
     * @alpha
     */
    enableBackToTop?: boolean;
    /**
     * 启用 flexbox 布局。开启后，当前节点声明了 display: flex 就会成为 flex container，并作用于其孩子节点。
     * @alpha
     */
    enableFlex?: boolean;
    /**
     * 开启 scroll anchoring 特性，即控制滚动位置不随内容变化而抖动，仅在 iOS 下生效，安卓下可参考 CSS overflow-anchor 属性。
     * @alpha
     */
    scrollAnchoring?: boolean;
    /**
     * 滚动到顶部/左边时触发
     */
    onScrollToUpper?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 滚动到底部/右边时触发
     */
    onScrollToLower?: (event: CustomEvent<Record<string, unknown>>) => void;
    /**
     * 滚动时触发，event.detail = {scrollLeft, scrollTop, scrollHeight, scrollWidth, deltaX, deltaY}
     */
    onScroll?: (event: CustomEvent<{
        scrollLeft: number;
        scrollTop: number;
        scrollHeight: number;
        scrollWidth: number;
        deltaX: number;
        deltaY: number;
    }>) => void;
}
