import type { CustomEvent } from "../../constructors/events";
declare const confirmTypes: readonly [
    "return",
    "send",
    "search",
    "next",
    "go",
    "done"
];
/**
 * @value 'send' 右下角按钮为“发送”
 * @value 'search' 右下角按钮为“搜索”
 * @value 'next' 右下角按钮为“下一个”
 * @value 'go' 右下角按钮为“前往”
 * @value 'done' 右下角按钮为“完成”
 * @value 'return' 右下角按钮为“换行”
 */
declare type ConfirmTypes = typeof confirmTypes[number];
/**
 * 多行输入框。该组件是原生组件，样式和行为和 HTML 有所差异，不允许嵌套其他组件。
 *
 * @version {"kma":"1.1.0","ide":"1.22.0"}
 *
 */
export declare interface TextareaProps {
    /**
     * 在表单中的字段名
     */
    name?: string;
    /**
     * 输入框的内容
     */
    value?: string;
    /**
     * 最大输入长度，设置为 -1 的时候不限制最大长度
     */
    maxlength?: number;
    /**
     * 是否禁用
     */
    disabled?: boolean;
    /**
     * 输入框为空时占位符
     */
    placeholder?: string;
    /**
     * 指定 placeholder 的样式，目前仅支持 color , font-size 和 font-weight
     */
    placeholderStyle?: string;
    /**
     * 自动聚焦，拉起键盘。
     */
    autoFocus?: boolean;
    /**
     * 获取焦点
     */
    focus?: boolean;
    /**
     * 如果 textarea 是在一个 position:fixed 的区域，需要显示指定属性 fixed 为 true
     */
    fixed?: boolean;
    /**
     * 光标默认色, 目前支持hex颜色码
     */
    cursorColor?: string;
    /**
     * 键盘弹起时，是否自动上推页面
     * @alpha
     */
    adjustPosition?: boolean;
    /**
     * 是否自动增高，设置 auto-height 时，style.height 不生效
     */
    autoHeight?: boolean;
    /**
     * 点击键盘右下角按钮时是否保持键盘不收起
     * @alpha
     */
    confirmHold?: boolean;
    /**
     * focus 时，点击页面的时候不收起键盘
     * @alpha
     */
    holdKeyboard?: boolean;
    /**
     * 设置键盘右下角按钮的文字
     * @alpha
     */
    confirmType?: ConfirmTypes;
    /**
     * 输入框聚焦时触发，event.detail = { value, height }，height 为键盘高度
     * @alpha
     */
    onFocus?: (event: CustomEvent<{
        value: string;
        height: number;
    }>) => void;
    /**
     * 输入框失去焦点时触发，event.detail = {value, cursor}
     * @alpha
     */
    onBlur?: (event: CustomEvent<{
        value: string;
        cursor: number;
    }>) => void;
    /**
     * 输入框行数变化时调用，event.detail = {height: 0, heightRpx: 0, lineCount: 0}
     * @alpha
     */
    onLineChange?: (event: CustomEvent<{
        height: number;
        heightRpx: number;
        lineCount: number;
    }>) => void;
    /**
     * 当键盘输入时，触发 input 事件，event.detail = {value, cursor, keyCode}，keyCode 为键值，目前工具还不支持返回 keyCode 参数。bindinput 处理函数的返回值并不会反映到 textarea 上
     * @alpha
     */
    onInput?: (event: CustomEvent<{
        value: string;
        cursor: number;
        keyCode: number;
    }>) => void;
    /**
     * 点击完成时， 触发 confirm 事件，event.detail = {value: value}
     * @alpha
     */
    onConfirm?: (event: CustomEvent<{
        value: string;
    }>) => void;
    /**
     * 键盘高度发生变化的时候触发此事件，event.detail = {height: height, duration: duration}
     * @alpha
     */
    onKeyboardHeightChange?: (event: CustomEvent<{
        height: number;
        duration: number;
    }>) => void;
}
export {};
