import type { LaunchOptions } from "../apis/basic/app/LaunchOptions";
import type { PageNotFoundEvent } from "../apis/basic/app/PageNotFoundEvent";
import type { AnyObject } from "./common";
export interface AppOptions {
    /**
     * 生命周期回调—监听小程序初始化
     *
     * 小程序初始化完成时触发，全局只触发一次。
     */
    onLaunch(options: LaunchOptions): void;
    /**
     * 生命周期回调—监听小程序显示
     *
     * 小程序启动，或从后台进入前台显示时
     */
    onShow(options: LaunchOptions): void;
    /**
     * 生命周期回调—监听小程序隐藏
     *
     * 小程序从前台进入后台时
     */
    onHide(): void;
    /**
     * 错误监听函数
     *
     * 小程序发生脚本错误，或者 api
     */
    onError(error: Error): void;
    /**
     * 页面不存在监听函数
     *
     * 小程序要打开的页面不存在时触发，会带上页面信息回调该函数
     */
    onPageNotFound(options: PageNotFoundEvent): void;
}
export declare type GetApp = <T = AnyObject>() => Partial<AppOptions> & T;
export declare type AppConstructor = <T extends AnyObject>(options: Partial<AppOptions> & T) => T;
