import type { FullProperty, PropType } from "./component";
export declare type AnyObject = Record<string, any>;
export declare type DefaultData = AnyObject;
export declare type DefaultMethods = AnyObject;
export declare type DefaultProps = Record<string, null | FullProperty<any, boolean> | PropType<any>>;
export declare type PageShareAppMessageEvent = {
    /**
     *  转发事件来源
     * - 'button': 页面内转发按钮
     * - 'menu'：右上角转发菜单
     */
    from: 'button' | 'menu';
    /**
     * 分享类型
     */
    type: 'share' | 'plc' | 'favorite' | 'live' | 'videoPublish';
    /**
     * 如果 `from` 值是 `button`，则 `target` 是触发这次转发事件的 `button`，否则为 `undefined`
     */
    target?: any;
} & AnyObject;
export interface CustomShareContent {
    /**
     * 转发标题。默认值：当前小程序名称
     */
    title?: string;
    /**
     * 转发路径，必须是以 / 开头的完整路径。默认值：当前页面 path
     */
    path?: string;
    /**
     * 自定义图片路径，可以是本地文件路径、代码包文件路径或者网络图片路径。支持PNG及JPG。默认值：使用默认截图
     */
    imageUrl?: string;
    /**
     * 转发内容
     */
    desc?: string;
}
export interface PageTabItemTapEvent {
    /**
     * 被点击tabItem的序号，从0开始
     */
    index: number;
    /**
     * 被点击tabItem的页面路径
     */
    pagePath: string;
    /**
     * 被点击tabItem的按钮文字
     */
    text: string;
}
export interface PageScrollEvent {
    /**
     * 页面在垂直方向已滚动的距离,单位 px
     */
    scrollTop: number;
}
export interface PageResizeEvent {
    /**
     * 变化后窗口尺寸
     */
    size: {
        /**
         * 变化后的窗口宽度，单位 px
         */
        windowWidth: number;
        /**
         * 变化后的窗口高度，单位 px
         */
        windowHeight: number;
    };
}
