import type { AdProps } from '../components';
import type { ButtonProps } from '../components';
import type { CameraProps } from '../components';
import type { CanvasProps } from '../components';
import type { CheckboxGroupProps } from '../components';
import type { CoverImageProps } from '../components';
import type { FormProps } from '../components';
import type { ImageProps } from '../components';
import type { InputProps } from '../components';
import type { MovableViewProps } from '../components';
import type { BasePickerProps } from '../components';
import type { SelectorPickerProps } from '../components';
import type { MultiSelectorPickerProps } from '../components';
import type { TimePickerProps } from '../components';
import type { DatePickerProps } from '../components';
import type { RegionPickerProps } from '../components';
import type { PickerViewProps } from '../components';
import type { ProgressProps } from '../components';
import type { RadioGroupProps } from '../components';
import type { ScrollViewProps } from '../components';
import type { SliderProps } from '../components';
import type { SwiperProps } from '../components';
import type { SwitchProps } from '../components';
import type { TextareaProps } from '../components';
import type { VideoProps } from '../components';
import type { WebViewProps } from '../components';

import type { AnyObject } from "./common";
interface Target<DataSet extends AnyObject = AnyObject> {
    /** 事件组件的 id */
    id: string;
    /** 当前组件的类型 */
    tagName?: string | undefined;
    /** 事件组件上由 `data-` 开头的自定义属性组成的集合 */
    dataset: DataSet;
    /** 距离页面顶部的偏移量 */
    offsetTop: number;
    /** 距离页面左边的偏移量 */
    offsetLeft: number;
}
/** 基础事件参数 */
interface BaseEvent<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset> {
    /** 事件类型 */
    type: string;
    /** 页面打开到触发事件所经过的毫秒数 */
    /** 事件冒泡路径上所有由 `mark:` 开头的自定义属性组成的集合 */
    /** 触发事件的源组件 */
    target: Target<TargetDataset>;
    /** 事件绑定的当前组件 */
    currentTarget: Target<CurrentTargetDataset>;
}
export declare type HandlerDetail<T> = T extends (e: CustomEvent<infer Detail>) => any ? Detail : never;
/** 自定义事件 */
export interface CustomEvent<Detail = any, CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset> extends BaseEvent<CurrentTargetDataset, TargetDataset> {
    /** 额外的信息 */
    detail: Detail;
}
/** Touch 对象 */
interface TouchDetail {
    /** 距离页面可显示区域 (屏幕除去导航条) 左上角距离，横向为 X 轴 */
    clientX: number;
    /** 距离页面可显示区域 (屏幕除去导航条) 左上角距离，纵向为 Y 轴 */
    clientY: number;
    /** 触摸点的标识符 */
    identifier: number;
    /** 距离文档左上角的距离，文档的左上角为原点，横向为 X 轴 */
    pageX: number;
    /** 距离文档左上角的距离，文档的左上角为原点，纵向为 Y 轴 */
    pageY: number;
}
/** 触摸事件 */
export interface TouchEvent<Detail extends AnyObject = AnyObject, T extends TouchDetail = TouchDetail, CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset> extends CustomEvent<Detail, CurrentTargetDataset, TargetDataset> {
    /** 触摸事件，当前停留在屏幕中的触摸点信息的数组 */
    touches: T[];
    /** 触摸事件，当前变化的触摸点信息的数组 */
    changedTouches: T[];
}
/** 点击事件 */
export declare type TapEvent<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset> = CustomEvent<{
    /** 点击的 x 坐标 */
    x: number;
    /** 点击的 y 坐标 */
    y: number;
}, CurrentTargetDataset, TargetDataset>;
export {};

/**
 * ad 组件的 load 事件
 */
export type AdLoadEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<AdProps['onLoad']>, CurrentTargetDataset, TargetDataset>;

/**
 * ad 组件的 error 事件
 */
export type AdErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<AdProps['onError']>, CurrentTargetDataset, TargetDataset>;

/**
 * ad 组件的 close 事件
 */
export type AdCloseEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<AdProps['onClose']>, CurrentTargetDataset, TargetDataset>;

/**
 * button 组件的 getuserinfo 事件
 */
export type ButtonGetUserInfoEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ButtonProps['onGetUserInfo']>, CurrentTargetDataset, TargetDataset>;

/**
 * button 组件的 getphonenumber 事件
 */
export type ButtonGetPhoneNumberEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ButtonProps['onGetPhoneNumber']>, CurrentTargetDataset, TargetDataset>;

/**
 * button 组件的 error 事件
 */
export type ButtonErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ButtonProps['onError']>, CurrentTargetDataset, TargetDataset>;

/**
 * button 组件的 opensetting 事件
 */
export type ButtonOpenSettingEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ButtonProps['onOpenSetting']>, CurrentTargetDataset, TargetDataset>;

/**
 * button 组件的 launchapp 事件
 */
export type ButtonLaunchAppEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ButtonProps['onLaunchApp']>, CurrentTargetDataset, TargetDataset>;

/**
 * button 组件的 addshortcut 事件
 */
export type ButtonAddShortcutEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ButtonProps['onAddShortcut']>, CurrentTargetDataset, TargetDataset>;

/**
 * camera 组件的 stop 事件
 */
export type CameraStopEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CameraProps['onStop']>, CurrentTargetDataset, TargetDataset>;

/**
 * camera 组件的 error 事件
 */
export type CameraErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CameraProps['onError']>, CurrentTargetDataset, TargetDataset>;

/**
 * camera 组件的 initdone 事件
 */
export type CameraInitDoneEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CameraProps['onInitDone']>, CurrentTargetDataset, TargetDataset>;

/**
 * camera 组件的 scancode 事件
 */
export type CameraScanCodeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CameraProps['onScanCode']>, CurrentTargetDataset, TargetDataset>;

/**
 * canvas 组件的 canvastouchstart 事件
 */
export type CanvasCanvasTouchStartEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CanvasProps['onCanvasTouchStart']>, CurrentTargetDataset, TargetDataset>;

/**
 * canvas 组件的 canvastouchmove 事件
 */
export type CanvasCanvasTouchMoveEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CanvasProps['onCanvasTouchMove']>, CurrentTargetDataset, TargetDataset>;

/**
 * canvas 组件的 canvastouchend 事件
 */
export type CanvasCanvasTouchEndEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CanvasProps['onCanvasTouchEnd']>, CurrentTargetDataset, TargetDataset>;

/**
 * canvas 组件的 canvastouchcancel 事件
 */
export type CanvasCanvasTouchCancelEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CanvasProps['onCanvasTouchCancel']>, CurrentTargetDataset, TargetDataset>;

/**
 * canvas 组件的 canvaslongtap 事件
 */
export type CanvasCanvasLongTapEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CanvasProps['onCanvasLongTap']>, CurrentTargetDataset, TargetDataset>;

/**
 * canvas 组件的 canvaserror 事件
 */
export type CanvasCanvasErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CanvasProps['onCanvasError']>, CurrentTargetDataset, TargetDataset>;

/**
 * checkbox-group 组件的 change 事件
 */
export type CheckboxGroupChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CheckboxGroupProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * cover-image 组件的 load 事件
 */
export type CoverImageLoadEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CoverImageProps['onLoad']>, CurrentTargetDataset, TargetDataset>;

/**
 * cover-image 组件的 error 事件
 */
export type CoverImageErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<CoverImageProps['onError']>, CurrentTargetDataset, TargetDataset>;

/**
 * form 组件的 submit 事件
 */
export type FormSubmitEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<FormProps['onSubmit']>, CurrentTargetDataset, TargetDataset>;

/**
 * form 组件的 reset 事件
 */
export type FormResetEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<FormProps['onReset']>, CurrentTargetDataset, TargetDataset>;

/**
 * image 组件的 error 事件
 */
export type ImageErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ImageProps['onError']>, CurrentTargetDataset, TargetDataset>;

/**
 * image 组件的 load 事件
 */
export type ImageLoadEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ImageProps['onLoad']>, CurrentTargetDataset, TargetDataset>;

/**
 * input 组件的 input 事件
 */
export type InputInputEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<InputProps['onInput']>, CurrentTargetDataset, TargetDataset>;

/**
 * input 组件的 focus 事件
 */
export type InputFocusEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<InputProps['onFocus']>, CurrentTargetDataset, TargetDataset>;

/**
 * input 组件的 blur 事件
 */
export type InputBlurEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<InputProps['onBlur']>, CurrentTargetDataset, TargetDataset>;

/**
 * input 组件的 confirm 事件
 */
export type InputConfirmEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<InputProps['onConfirm']>, CurrentTargetDataset, TargetDataset>;

/**
 * input 组件的 keyboardheightchange 事件
 */
export type InputKeyboardHeightChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<InputProps['onKeyboardHeightChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * movable-view 组件的 change 事件
 */
export type MovableViewChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<MovableViewProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * movable-view 组件的 scale 事件
 */
export type MovableViewScaleEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<MovableViewProps['onScale']>, CurrentTargetDataset, TargetDataset>;

/**
 * base-picker 组件的 cancel 事件
 */
export type BasePickerCancelEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<BasePickerProps['onCancel']>, CurrentTargetDataset, TargetDataset>;

/**
 * selector-picker 组件的 change 事件
 */
export type SelectorPickerChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SelectorPickerProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * multi-selector-picker 组件的 change 事件
 */
export type MultiSelectorPickerChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<MultiSelectorPickerProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * multi-selector-picker 组件的 columnchange 事件
 */
export type MultiSelectorPickerColumnchangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<MultiSelectorPickerProps['onColumnchange']>, CurrentTargetDataset, TargetDataset>;

/**
 * time-picker 组件的 change 事件
 */
export type TimePickerChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TimePickerProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * date-picker 组件的 change 事件
 */
export type DatePickerChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<DatePickerProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * region-picker 组件的 change 事件
 */
export type RegionPickerChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<RegionPickerProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * picker-view 组件的 change 事件
 */
export type PickerViewChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<PickerViewProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * picker-view 组件的 pickstart 事件
 */
export type PickerViewPickStartEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<PickerViewProps['onPickStart']>, CurrentTargetDataset, TargetDataset>;

/**
 * picker-view 组件的 pickend 事件
 */
export type PickerViewPickEndEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<PickerViewProps['onPickEnd']>, CurrentTargetDataset, TargetDataset>;

/**
 * progress 组件的 activeend 事件
 */
export type ProgressActiveEndEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ProgressProps['onActiveEnd']>, CurrentTargetDataset, TargetDataset>;

/**
 * radio-group 组件的 change 事件
 */
export type RadioGroupChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<RadioGroupProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * scroll-view 组件的 scrolltoupper 事件
 */
export type ScrollViewScrollToUpperEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ScrollViewProps['onScrollToUpper']>, CurrentTargetDataset, TargetDataset>;

/**
 * scroll-view 组件的 scrolltolower 事件
 */
export type ScrollViewScrollToLowerEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ScrollViewProps['onScrollToLower']>, CurrentTargetDataset, TargetDataset>;

/**
 * scroll-view 组件的 scroll 事件
 */
export type ScrollViewScrollEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<ScrollViewProps['onScroll']>, CurrentTargetDataset, TargetDataset>;

/**
 * slider 组件的 change 事件
 */
export type SliderChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SliderProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * slider 组件的 changing 事件
 */
export type SliderChangingEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SliderProps['onChanging']>, CurrentTargetDataset, TargetDataset>;

/**
 * swiper 组件的 change 事件
 */
export type SwiperChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SwiperProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * swiper 组件的 transition 事件
 */
export type SwiperTransitionEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SwiperProps['onTransition']>, CurrentTargetDataset, TargetDataset>;

/**
 * swiper 组件的 animationfinish 事件
 */
export type SwiperAnimationFinishEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SwiperProps['onAnimationFinish']>, CurrentTargetDataset, TargetDataset>;

/**
 * switch 组件的 change 事件
 */
export type SwitchChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<SwitchProps['onChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * textarea 组件的 focus 事件
 */
export type TextareaFocusEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TextareaProps['onFocus']>, CurrentTargetDataset, TargetDataset>;

/**
 * textarea 组件的 blur 事件
 */
export type TextareaBlurEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TextareaProps['onBlur']>, CurrentTargetDataset, TargetDataset>;

/**
 * textarea 组件的 linechange 事件
 */
export type TextareaLineChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TextareaProps['onLineChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * textarea 组件的 input 事件
 */
export type TextareaInputEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TextareaProps['onInput']>, CurrentTargetDataset, TargetDataset>;

/**
 * textarea 组件的 confirm 事件
 */
export type TextareaConfirmEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TextareaProps['onConfirm']>, CurrentTargetDataset, TargetDataset>;

/**
 * textarea 组件的 keyboardheightchange 事件
 */
export type TextareaKeyboardHeightChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<TextareaProps['onKeyboardHeightChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 play 事件
 */
export type VideoPlayEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onPlay']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 pause 事件
 */
export type VideoPauseEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onPause']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 ended 事件
 */
export type VideoEndedEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onEnded']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 timeupdate 事件
 */
export type VideoTimeUpdateEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onTimeUpdate']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 fullscreenchange 事件
 */
export type VideoFullScreenChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onFullScreenChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 error 事件
 */
export type VideoErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onError']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 rendererror 事件
 */
export type VideoRenderErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onRenderError']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 castinguserselect 事件
 */
export type VideoCastingUserSelectEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onCastingUserSelect']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 castingstatechange 事件
 */
export type VideoCastingStateChangeEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onCastingStateChange']>, CurrentTargetDataset, TargetDataset>;

/**
 * video 组件的 castinginterrupt 事件
 */
export type VideoCastingInterruptEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<VideoProps['onCastingInterrupt']>, CurrentTargetDataset, TargetDataset>;

/**
 * web-view 组件的 message 事件
 */
export type WebViewMessageEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<WebViewProps['onMessage']>, CurrentTargetDataset, TargetDataset>;

/**
 * web-view 组件的 load 事件
 */
export type WebViewLoadEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<WebViewProps['onLoad']>, CurrentTargetDataset, TargetDataset>;

/**
 * web-view 组件的 error 事件
 */
export type WebViewErrorEvent
<CurrentTargetDataset extends AnyObject = AnyObject, TargetDataset extends AnyObject = CurrentTargetDataset>
    = CustomEvent<HandlerDetail<WebViewProps['onError']>, CurrentTargetDataset, TargetDataset>;

