import type {
    AppConstructor,
    GetCurrentPages,
    GetApp,
    PageConstructor,
    ComponentConstructor,
    BehaviorConstructor,
} from './constructors';
import type { apis } from './apis';
import { JSXElement, JSXIntrinsicElements } from './components';

declare global {
    namespace JSX {
        type Element = JSXElement
        type IntrinsicElements = JSXIntrinsicElements
    }
    /**
     * API 的全局对象。
     */
    const ks: typeof apis;
    /**
     * 注册小程序中的一个页面。指定页面的初始数据、生命周期回调、事件处理函数等。
     */
    const Page: PageConstructor;
    /**
     * 创建自定义组件。
     */
    const Component: ComponentConstructor;
    /**
     * 注册一个 `behavior`。
     */
    const Behavior: BehaviorConstructor;
    /**
     * 获取到小程序全局唯一的 App 实例。
     */
    const getApp: GetApp;
    /**
     * 获取当前页面栈。数组中第一个元素为首页，最后一个元素为当前页面。
     */
    const getCurrentPages: GetCurrentPages;
    /**
     * 注册小程序。
     *
     * **注意：App() 必须在 `app.js` 中调用，必须调用且只能调用一次。不然会出现无法预期的后果。**
     */
    const App: AppConstructor;

    /**
     * 当前模块对象
     */
    const module: {
        /**
         * 模块向外暴露的对象，使用 `require` 引用该模块时可以获取
         */
        exports: any;
    }

    /**
     * 引入模块。返回模块通过 `module.exports` 或 `exports` 暴露的接口。
     * @param path 需要引入模块文件相对于当前文件的相对路径
     */
    function require(path: string): any;

    const console: {
        /**
         * 向调试面板中打印 log 日志
         * @param args 日志内容
         */
        log(...args: any): void
        /**
         * 向调试面板中打印 info 日志
         * @param args 日志内容
         */
        info(...args: any): void
        /**
         * 向调试面板中打印 warn 日志
         * @param args 日志内容
         */
        warn(...args: any): void
        /**
         * 向调试面板中打印 debug 日志
         * @param args 日志内容
         */
        debug(...args: any): void
        /**
         * 向调试面板中打印 error 日志
         * @param args 日志内容
         */
        error(...args: any): void
    }

    /**
     * `module.exports` 的引用
     */
    const exports: any

    /**
     * 取消由 setInterval 设置的定时器。
     * @param intervalId 要取消的定时器 Id
     */
    function clearTimeout(intervalId: number): void

    /**
     * 取消由 setInterval 设置的定时器。
     * @param timeoutId 要取消的定时器 Id
     */
    function clearInterval(timeoutId: number): void


    /**
     * 设定一个定时器。按照指定的周期（以毫秒计）来执行注册的回调函数。
     * @param callback 回调函数
     * @param interval 执行回调函数之间的时间间隔，单位 ms
     * @param args 附加参数，它们会作为参数传递给回调函数
     */
    function setInterval(callback: (...args: any[]) => any, interval?: number, ...args: any[]): number


    /**
     * 设定一个定时器。在定时到期以后执行注册的回调函数.
     * @param callback 回调函数
     * @param delay 延迟的时间，函数的调用会在该延迟之后发生，单位 ms
     * @param args 附加参数，它们会作为参数传递给回调函数
     */
    function setTimeout(callback: (...args: any[]) => any, delay?: number, ...args: any[]): number
}
